@@ -1,5 +1,5 @@
 # This file is part of tdmclient-ty.
-# Copyright 2021 ECOLE POLYTECHNIQUE FEDERALE DE LAUSANNE,
+# Copyright 2021-2022 ECOLE POLYTECHNIQUE FEDERALE DE LAUSANNE,
 # Miniature Mobile Robots group, Switzerland
 # Author: Yves Piguet
 #
@@ -68,7 +68,7 @@ def print_transpiled_code():
     try:
         transpiler.transpile()
     except TranspilerError as error:
-        print_error(f"\n{error.message}\n")
+        print_error(f"\n{error}\n")
         return
     program = transpiler.get_output()
 
@@ -116,7 +116,7 @@ def run():
     try:
         transpiler.transpile()
     except TranspilerError as error:
-        print_error(f"\n{error.message}\n")
+        print_error(f"\n{error}\n")
         return
     program = transpiler.get_output()
 
@@ -148,7 +148,12 @@ def run():
             await node.register_events(events)
         error = await node.compile(program)
         if error is not None:
-            print_error(f"Compilation error: {error['error_msg']}\n")
+            if "error_msg" in error:
+                print_error(f"Compilation error: {error['error_msg']}\n")
+            elif "error_code" in error:
+                print_error(f"Cannot run program (error {error['error_code']})")
+            else:
+                print_error(f"Cannot run program\n")
         else:
             client.clear_events_received_listeners()
             if len(events) > 0:
